#
# spec file for package libportal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           libportal
Version:        0.9.0
Release:        1.3
Summary:        A GIO-style async API for most Flatpak portals
License:        LGPL-3.0-or-later
URL:            https://github.com/flatpak/libportal
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  meson >= 0.46.0
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Test)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(vapigen)

%description
A GIO-style async API for most Flatpak portals.

%package     -n %{name}%{sover}
Summary:        A GIO-style async API for most Flatpak portals
Obsoletes:      libportal-1
Provides:       libportal-1

%description -n %{name}%{sover}
A GIO-style async API for most Flatpak portals.
This package contains the shared library of %{name}.

%package     -n %{name}-gtk3-%{sover}
Summary:        GTK3 integration for libportal

%description -n %{name}-gtk3-%{sover}
A GIO-style async API for most Flatpak portals.
This package contains the shared library of %{name}.

%package     -n %{name}-gtk4-%{sover}
Summary:        GTK4 integration for libportal

%description -n %{name}-gtk4-%{sover}
A GIO-style async API for most Flatpak portals.
This package contains the shared library of %{name}.

%package     -n %{name}-qt5-%{sover}
Summary:        Qt5 integration for libportal

%description -n %{name}-qt5-%{sover}
A GIO-style async API for most Flatpak portals.
This package contains the shared library of %{name}.

%package     -n %{name}-qt6-%{sover}
Summary:        Qt6 integration for libportal

%description -n %{name}-qt6-%{sover}
A GIO-style async API for most Flatpak portals.
This package contains the shared library of %{name}.

%package -n     typelib-1_0-Xdp-1_0
Summary:        Introspections files for libportal

%description -n typelib-1_0-Xdp-1_0
A GIO-style async API for most Flatpak portals.
This package contains the introspection files of %{name}.

%package -n     typelib-1_0-XdpGtk3-1_0
Summary:        Introspections files for libportal

%description -n typelib-1_0-XdpGtk3-1_0
A GIO-style async API for most Flatpak portals.
This package contains the introspection files of %{name}.

%package -n     typelib-1_0-XdpGtk4-1_0
Summary:        Introspections files for libportal

%description -n typelib-1_0-XdpGtk4-1_0
A GIO-style async API for most Flatpak portals.
This package contains the introspection files of %{name}.

%package devel
Summary:        Headers for libportal, a GIO async API for Flatpak portals
Requires:       %{name}%{sover} = %{version}
Requires:       typelib-1_0-Xdp-1_0 = %{version}

%description devel
The %{name}-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%package gtk3-devel
Summary:        Headers for the libportal GTK3 integration library
Requires:       %{name}-gtk3-%{sover} = %{version}
Requires:       typelib-1_0-XdpGtk3-1_0 = %{version}

%description gtk3-devel
The %{name}-gtk3-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%package gtk4-devel
Summary:        Headers for the libportal GTK4 integration library
Requires:       %{name}-gtk4-%{sover} = %{version}
Requires:       typelib-1_0-XdpGtk4-1_0 = %{version}

%description gtk4-devel
The %{name}-gtk4-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%package qt5-devel
Summary:        Headers for libportal Qt5 integration library
Requires:       %{name}-qt5-%{sover} = %{version}

%description qt5-devel
The %{name}-qt5-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%package qt6-devel
Summary:        Headers for libportal Qt6 integration library
Requires:       %{name}-qt6-%{sover} = %{version}

%description qt6-devel
The %{name}-qt6-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n %{name}%{sover}
%ldconfig_scriptlets -n %{name}-gtk3-%{sover}
%ldconfig_scriptlets -n %{name}-gtk4-%{sover}
%ldconfig_scriptlets -n %{name}-qt5-%{sover}
%ldconfig_scriptlets -n %{name}-qt6-%{sover}

%files -n %{name}%{sover}
%license COPYING
%{_libdir}/libportal.so.%{sover}*

%files -n %{name}-gtk3-%{sover}
%{_libdir}/libportal-gtk3.so.%{sover}*

%files -n %{name}-gtk4-%{sover}
%{_libdir}/libportal-gtk4.so.%{sover}*

%files -n %{name}-qt5-%{sover}
%{_libdir}/libportal-qt5.so.%{sover}*

%files -n %{name}-qt6-%{sover}
%{_libdir}/libportal-qt6.so.%{sover}*

%files -n typelib-1_0-Xdp-1_0
%{_libdir}/girepository-1.0/Xdp-1.0.typelib

%files -n typelib-1_0-XdpGtk3-1_0
%{_libdir}/girepository-1.0/XdpGtk3-1.0.typelib

%files -n typelib-1_0-XdpGtk4-1_0
%{_libdir}/girepository-1.0/XdpGtk4-1.0.typelib

%files devel
%doc NEWS README.md
%doc %{_datadir}/doc/libportal-1
%{_includedir}/%{name}
%{_libdir}/libportal.so
%{_libdir}/pkgconfig/libportal.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libportal.deps
%{_datadir}/vala/vapi/libportal.vapi
%{_datadir}/gir-1.0/Xdp-1.0.gir

%files gtk3-devel
%{_includedir}/libportal-gtk3
%{_libdir}/libportal-gtk3.so
%{_libdir}/pkgconfig/libportal-gtk3.pc
%{_datadir}/gir-1.0/XdpGtk3-1.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libportal-gtk3.deps
%{_datadir}/vala/vapi/libportal-gtk3.vapi

%files gtk4-devel
%{_includedir}/libportal-gtk4
%{_libdir}/libportal-gtk4.so
%{_libdir}/pkgconfig/libportal-gtk4.pc
%{_datadir}/gir-1.0/XdpGtk4-1.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libportal-gtk4.deps
%{_datadir}/vala/vapi/libportal-gtk4.vapi

%files qt5-devel
%{_includedir}/libportal-qt5
%{_libdir}/libportal-qt5.so
%{_libdir}/pkgconfig/libportal-qt5.pc

%files qt6-devel
%{_includedir}/libportal-qt6
%{_libdir}/libportal-qt6.so
%{_libdir}/pkgconfig/libportal-qt6.pc

%changelog
* Sat Dec 21 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.9.0:
  + Features: Introduce support for the Notification v2 portal
    version.
  + Bug fixes:
  - Fix a file descriptor leak in the Mail portal code
  - Fix some minor memory leaks
* Wed Sep  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.1:
  + Fix a regression in the Remote Desktop where it wouldn't work
    with the ScreenCast portal correctly.
  + Use non-deprecated functions in the GTK4 code.
  + Run tests in CI so we catch regressions earlier.
  + Make Qt tests use QTEST_GUILESS_MAIN.
  + Fix an Input Capture test.
- Changes from version 0.8.0:
  + Add API to allow for persistence on RemoteDesktop sessions.
  + Implement support for the Input Capture portal.
  + Add support for Qt 6.
  + Support xdg-foreign with Qt 6.
  + Fix screencasting on wlroots-based compositors.
- Build the new Qt 6 support:
  + Add qt6-gui-private-devel, pkgconfig(Qt6Core), pkgconfig(Qt6Gui),
    pkgconfig(Qt6Test) and pkgconfig(Qt6Widgets) BuildRequires.
  + Add new sub-packages: libportal-qt6-1 and libportal-qt6-devel.
  + Use ldconfig_scriptlets macro for post(un) handling of the new
    shared library.
* Wed Nov 22 2023 Jan Engelhardt <jengelh@inai.de>
- Replace copypasted summaries by something more concrete
* Wed Nov 15 2023 Yifan Jiang <yfjiang@suse.com>
- Rename package name from libportal-1 to libportal1, this is
  necessary to conform to the shared library policy:
  https://en.opensuse.org/openSUSE:Shared_library_packaging_policy#Package_naming
* Sun Sep 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.7.1:
  + Restore ability to call g_object_new (XDP_TYPE_PORTAL, ...).
* Wed Sep  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.7:
  + Add support for the new SetStatus() method of the Background
    portal.
  + Add support for the new ConnectToEIS() method of the Remote
    Desktop portal.
  + Improve unit and integration tests.
  + Documentation improvements.
  + CI improvements.
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.6:
  + New portal support: Dynamic launcher.
  + Add API for checking for flatpak/snap sandbox.
  + Fix a bug where the callback setup by libportal for a
    GCancellable was not properly canceled in case a portal method
    call was not successful, which can lead to a double free seg
    fault.
  + libportal-qt:
  - Add convenient functions to better deal with GVariants.
  - Use a global instance of XdpPortal object.
  - Make filechooserFilterToGVariant() public.
  + camera: Use correct variant for is_camera_present().
  + portal-test-gtk3: Fix incorrect paths used in tests.
  + Documentation improvements.
  + CI improvements.
- Add pkgconfig(Qt5Test) BuildRequires: New dependency.
* Tue Jan 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Split devel subpackage into 4, libportal-devel,
  libportal-gt3-devel, libportal-gtk4-devel and
  libportal-qt5-devel, minimize dependencies pulled in for packages
  depending on the various devel packages.
* Fri Jan  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5:
  + Relicence to LGPL 3.0
  + Fix a refcounting error in xdp_parent_free
  + location: Fix location-updated signature
  + remote:
  - Add cursor mode
  - Support virtual screens
  - Support persistent sessions
  + Rename qt backend to qt5
  + Install separate libraries: libportal-gtk3, libportal-gtk4,
    libportal-qt5
  + Add gobject-introspection support
  + Add vala support
  + Add a GTK4 portal test app, using gjs
  + Build documentation using gi-docgen
- Change license from LGPL-2.1-or-later to LGPL-3.0-or-later
  following upstream.
- Add c_compiler, c++_compiler, pkgconfig(gi-docgen),
  pkgconfig(gobject-introspection-1.0), pkgconfig(gtk+-3.0),
  pkgconfig(gtk4), pkgconfig(vapigen), pkgconfig(Qt5Core),
  pkgconfig(Qt5Gui), pkgconfig(Qt5Widgets) and
  pkgconfig(Qt5X11Extras) BuildRequires: New dependencies.
- Drop gtk-doc BuildRequires, no longer needed, nor used.
- Replace post(un) handling with ldconfig_scriptlets macro.
- Bump sover to 1 following upstream changes, drop libportal0
  subpackage as it is no longer built, add new subpackages:
  libportal-1, libportal-gtk3, libportal-gtk4, libportal-qt5,
  typelib-1_0-Xdp-1_0, typelib-1_0-XdpGtk3-1_0 and
  typelib-1_0-XdpGtk4-1_0.
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.4:
  + Make GTK4 support work with GTK 4.0
  + Qt5 support
  + OpenURI: Support write access
  + Build fixes
  + Add more tests
  + Require GLib 2.58
* Sat Dec 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Inital build for openSUSE, version 0.3.
